Having too many locals may indicate that you're doing too much in a function and that
classes regrouping some attributes could be created. Maybe operations could be separated in
multiple functions. Are all your variables really closely related ?
